@@ -3,6 +3,7 @@ Reconstruct alignments from mutations inferred on the tree
 """
 
 from Bio import SeqIO, Seq, SeqRecord, Phylo
+from .io.file import open_file
 from .utils import read_node_data
 
 
@@ -71,7 +72,7 @@ def run(args):
     #if VCF, read in the reference seq for each gene, put on root
     if(is_vcf):
         node_data["nodes"][root_node]['aa_sequences'] = {}
-        with open(args.vcf_aa_reference, encoding='utf-8') as handle:
+        with open_file(args.vcf_aa_reference) as handle:
             for record in SeqIO.parse(handle, "fasta"):
                 if record.id==args.gene:
                     #'root' may not be same as 'reference', so apply any mutations at root here!
