@@ -6,6 +6,9 @@ import argparse
 import json
 from numpy import ndarray
 
+from augur.argparse_ import ExtendOverwriteDefault
+
+
 def get_trait(attributes, trait, dateFormat):
     if trait in ["num_date", "date"]:
         try:
@@ -27,8 +30,8 @@ if __name__=="__main__":
     parser = argparse.ArgumentParser(description = "Process a given JSONs")
     parser.add_argument('--json', required=True, type=str, help="prepared JSON")
     parser.add_argument('--trait', required=True, type=str, help="prepared JSON")
-    parser.add_argument('--header', nargs='*', type=str, help="header fields")
-    parser.add_argument('--date_format', nargs='*', default=["%Y-%m-%d"], type=str, help="if needed. default: [%%Y-%%m-%%d]")
+    parser.add_argument('--header', nargs='*', action='extend', type=str, help="header fields")
+    parser.add_argument('--date_format', nargs='*', action=ExtendOverwriteDefault, default=["%Y-%m-%d"], type=str, help="if needed. default: [%%Y-%%m-%%d]")
     params = parser.parse_args()
 
     with open(params.json, 'r') as fh:
