@@ -385,12 +385,7 @@ class TestAlign:
         output = run("-s %s" % (test_file))
         assert output.keys() == test_seqs.keys()
         assert all(len(r.seq) == expected_length for r in output.values())
-    
-    def test_run_fill_gaps(self, test_file, run):
-        """All gaps should be filled when --fill-gaps is passed"""
-        output = run("-s %s --fill-gaps" % test_file)
-        assert all("-" not in r.seq for r in output.values())
-    
+
     def test_run_with_ref_name_no_alignment(self, test_with_ref, test_seqs, ref_seq, run):
         expected_length = len(ref_seq.seq) - ref_seq.seq.count("-")
         output = run("-s %s --reference-name %s" % (test_with_ref, ref_seq.id))
@@ -407,12 +402,12 @@ class TestAlign:
         assert output["PREFIX"].seq.startswith("---")
         assert output["SUFFIX"].seq.endswith("---")
     
-    def test_run_with_ref_seq_remove_reference(self, test_with_ref, ref_seq, run):
+    def test_run_with_reference_name_remove_reference(self, test_with_ref, ref_seq, run):
         expected_length = len(ref_seq.seq) - ref_seq.seq.count("-")
         output = run("-s %s --reference-name %s --remove-reference" % (test_file, ref_seq.id))
         assert ref_seq.id not in output
 
-    def test_run_with_ref_seq_remove_reference(self, test_file, ref_file, ref_seq, run):
+    def test_run_with_reference_sequence_remove_reference(self, test_file, ref_file, ref_seq, run):
         expected_length = len(ref_seq.seq) - ref_seq.seq.count("-")
         output = run("-s %s --reference-sequence %s --remove-reference" % (test_file, ref_file))
         assert ref_seq.id not in output
