@@ -17,14 +17,14 @@ class TestValidateExport():
         # Create a tree with unique tip names.
         tree = Bio.Phylo.read(StringIO("root(A, internal(B, C))"), "newick")
         metadata = {"A": {}, "B": {}, "C": {}, "root": {}, "internal": {}}
-        root = convert_tree_to_json_structure(tree.root, metadata)
+        root = convert_tree_to_json_structure(tree.root, metadata, None)
         ensure_no_duplicate_names(root, ValidateError)
 
     def test_export_with_duplicate_names(self):
         # Create a tree with duplicate tip names.
         tree = Bio.Phylo.read(StringIO("root(A, internal(B, B))"), "newick")
         metadata = {"A": {}, "B": {}, "root": {}, "internal": {}}
-        root = convert_tree_to_json_structure(tree.root, metadata)
+        root = convert_tree_to_json_structure(tree.root, metadata, None)
 
         with pytest.raises(ValidateError):
             ensure_no_duplicate_names(root, ValidateError)
